@@ -1,5 +1,6 @@
-from cvzone.Utils import stackImages, cornerRect, findContours, overlayPNG, rotateImage
+from cvzone.Utils import stackImages, cornerRect, findContours,\
+    overlayPNG, rotateImage, putTextRect
 from cvzone.ColorModule import ColorFinder
 from cvzone.FPS import FPS
 from cvzone.PIDModule import PID
-from cvzone.PlotModule import LivePlot
\ No newline at end of file
+from cvzone.PlotModule import LivePlot
